Filter overlaps from matches using only base R functionality
Source:R/base_fallback_helpers.R
filter_overlap_base.RdHelper function using only base R functionality used to identify which results from gregexpr overlap other matches and filter out shorter, overlapped results