Helper function to be used in a loop to check each pattern provided for matches when the compiled version isn't available
get_matches_base(string, pattern, i, ...)a character vector where replacements are sought
Character string to be matched in the given character vector
an iterator provided by a looping function
arguments to pass to gregexpr